@@ -3,17 +3,9 @@
   
   install_cgal <- isTRUE(Sys.getenv("CGAL_DOWNLOAD")  != "0")
   interact     <- interactive()
-  # on_cran      <- !identical(Sys.getenv("NOT_CRAN"), "true")
-  has_internet <- curl::has_internet()
   no_cgal      <- !cgal_is_installed()
   
-  if(no_cgal && has_internet && install_cgal && !interact ) {
-    tryCatch(suppressMessages(cgal_install()),
-             error = .cgal_install_error_catch
-             )
-  }
-  
-  .cgal_download_check() # will see if interactive and ask to download
+  .cgal_download_check() # will see if header files are found
   
 }
 
@@ -21,10 +13,10 @@
   
   .cgal_download_check() # will see if interactive and ask to download
   
-  packageStartupMessage("For more information about how to use the header files, see the CGAL documentation  at <https://www.cgal.org>. For more details on the license of the CGAL header files, lease see <https://www.cgal.org/license.html>. The header files as used in this package are under the GPL (v3+) license.\n
+  packageStartupMessage("For more information about how to use the header files, see the CGAL documentation  at <https://www.cgal.org>. The header files as setup by this package are under a GPL-3 license. For the use of the header files outside this package, please see <https://www.cgal.org/license.html>.\n
 Please cite this package if you use it. See citation('RcppCGAL').\n", domain = NULL, appendLF = TRUE)
   
-  if ( cgal_is_installed() && !is.na(.cgal_version_check()) ) {
+  if ( cgal_is_installed() ) {
     packageStartupMessage(cgal_pkg_state$VERSION, domain = NULL, appendLF = TRUE)
   }
   
